Changelog
---------
2016-10-28: v1.0.0
  * Stable release
  * Add sorting by weight and priority instead of only by priority

2015-06-08: v0.2.0
  * Look up SRV names in DNS additional records segment

2014-03-11: v0.1.0
  * Initial version
